@@ -3,11 +3,13 @@ from enum import Enum
 from dotenv import load_dotenv
 load_dotenv()
 
-MODELIFY_API_URL = "https://api.modelify.ai/v1"
+
+MODELIFY_API_URL = os.getenv("MODELIFY_API_URL", "https://api.modelify.ai/v1")
 MODELIFY_TOKEN_VALIDATION_URL = MODELIFY_API_URL + "/registry/me"
 MODELIFY_INFO_URL = MODELIFY_API_URL + "/info"
 MODELIFY_DEPLOY_URL =  MODELIFY_API_URL + "/registry/deploy"
-MODELIFY_PRESIGNED_URL = MODELIFY_API_URL + "/registry/presigned-url"
+MODELIFY_UPLOAD_URL = MODELIFY_API_URL + "/registry/upload-url"
+MODELIFY_DOWNLOAD_URL = MODELIFY_API_URL + "/registry/download-url"
 
 
 def get_app_folder() -> str:
@@ -21,7 +23,7 @@ class ModelifyFile(Enum):
         t = object.__new__(cls)
         t._value_ = value
         t._filename = file_name
-        t._content_Type = content_type
+        t._content_type = content_type
         return t
 
     
@@ -30,6 +32,7 @@ class ModelifyFile(Enum):
     PREPROCESS = ("PREPROCESS", "preprocess.pkl", "application/octet-stream")
     POSTPROCESS = ("POSTPROCESS", "postprocess.pkl", "application/octet-stream")
     REQUIREMENTS = ("REQUIREMENTS", "requirements.txt", "text/plain")
+    EXTERNAL_FILE = ("EXTERNAL_FILE", "external.py" , "text/x-python-script")
 
 
     def __repr__(self):
@@ -39,10 +42,6 @@ class ModelifyFile(Enum):
     def file_name(self):
         return self._filename
     
-    @property
-    def file_name(self):
-        return self._filename
-    
     @property
     def content_type(self):
-        return self._filename
\ No newline at end of file
+        return self._content_type
